scoretools.StaffGroup
=====================

.. inheritance-diagram:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup
   :private-bases:

.. autoclass:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.contents_duration

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.duration_in_seconds

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.engraver_consists

    Inherited from :py:class:`contexttools.Context <abjad.tools.contexttools.Context.Context.Context>`

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.engraver_removals

    Inherited from :py:class:`contexttools.Context <abjad.tools.contexttools.Context.Context.Context>`

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.is_semantic

    Inherited from :py:class:`contexttools.Context <abjad.tools.contexttools.Context.Context.Context>`

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.leaves

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.lilypond_format

    Inherited from :py:class:`contexttools.Context <abjad.tools.contexttools.Context.Context.Context>`

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.music

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.override

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.parent

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.preprolated_duration

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.prolated_duration

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.prolation

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.set

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.spanners

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.start_offset

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.start_offset_in_seconds

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.stop_offset

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.stop_offset_in_seconds

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.context_name

    Inherited from :py:class:`contexttools.Context <abjad.tools.contexttools.Context.Context.Context>`

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.is_nonsemantic

    Inherited from :py:class:`contexttools.Context <abjad.tools.contexttools.Context.Context.Context>`

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.is_parallel

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.name

    Inherited from :py:class:`contexttools.Context <abjad.tools.contexttools.Context.Context.Context>`

Methods
-------

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.append

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.extend

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.index

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.insert

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.pop

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.remove

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

Special Methods
---------------

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.__add__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.__contains__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.__delitem__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.__getitem__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.__iadd__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.__imul__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.__len__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.__mul__

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.__radd__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.__repr__

    Inherited from :py:class:`contexttools.Context <abjad.tools.contexttools.Context.Context.Context>`

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.__rmul__

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. automethod:: abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup.__setitem__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`
